@@ -9,7 +9,7 @@ import pandas as pd
 
 import fsspec
 
-from hypothesis import assume, given, settings
+from hypothesis import HealthCheck, assume, given, settings
 from hypothesis import strategies as st
 from tinydb import TinyDB, Query, where
 
@@ -46,7 +46,7 @@ class TestJson(unittest.TestCase):
 
         SimpleMultiIndexSchema.test(self, datasource, docs)
 
-    #FIXME: This test is failing, but it's not clear why.
+    # FIXME: This test is failing, but it's not clear why.
     # @given(InterpolatingSchema.list_strategy())
     # @settings(deadline=None)
     # def test_interpolated(self, docs: InterpolatingSchema):
@@ -55,15 +55,15 @@ class TestJson(unittest.TestCase):
     #     InterpolatingSchema.test(self, datasource, docs)
 
     @given(IntegerIntervalSchema.list_strategy())
-    @settings(deadline=None)
+    @settings(deadline=None, suppress_health_check=[HealthCheck.too_slow])
     def test_integer_interval(self, docs: IntegerIntervalSchema):
         datasource = []
 
         IntegerIntervalSchema.test(self, datasource, docs)
 
     @given(TimeIntervalSchema.list_strategy())
-    @settings(deadline=None)
+    @settings(deadline=None, suppress_health_check=[HealthCheck.too_slow])
     def test_time_interval(self, docs: TimeIntervalSchema):
         datasource = []
 
-        TimeIntervalSchema.test(self, datasource, docs)
\ No newline at end of file
+        TimeIntervalSchema.test(self, datasource, docs)
